@@ -2,4 +2,4 @@ from .entities import (
     Constructor,
     Method,
 )
-from .parser import Parser
+from .parser import TDApiParser
